#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-C267XiBM1AKCiPfbNM3TEg
key:                  persistent-test-2.13.1.3-C267XiBM1AKCiPfbNM3TEg
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  1964c838deb79607f9a32ea997bdf07b
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-C267XiBM1AKCiPfbNM3TEg
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-AYFl8XMhYILjNXxrnkZL0
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0 base-4.18.2.1
    blaze-html-0.9.2.0-FabkuXZBABUKDnPHGVQGa9 bytestring-0.11.5.3
    conduit-1.3.6.1-EmA1TJONA2cErpLghbE74P containers-0.6.7
    exceptions-0.10.7 hspec-2.11.6-LgTkwcDiraZ4go4CjZYNe1
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-E6BEj4druX86lEH66yAElM
    monad-control-1.0.3.1-JXzXgrKSU0X17nOjbMEv8z
    monad-logger-0.3.42-A5DJ2f0YH2kKVbhsHUA7Rk mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-4aAqGYQjW9n2dtsW58zyAj
    quickcheck-instances-0.3.33-J3oVwxB31Lj9vkFAleoxCk
    random-1.2.1.3-5RWjRNGMcAI4pn7QxDBoxf
    resourcet-1.2.6-6UHT6wOZljkBsLcdnEKCgw text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-Dib9v9t7s3p80Z6M50cYPb
    unliftio-0.2.25.1-3G7k8azuVYgEaJyxfwlJrh
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

